@@ -1,8 +1,7 @@
 #![no_std]
 #![unstable(feature = "panic_unwind", issue = "32837")]
 #![feature(link_cfg)]
-#![feature(native_link_modifiers_bundle)]
-#![feature(nll)]
+#![cfg_attr(bootstrap, feature(native_link_modifiers_bundle))]
 #![feature(staged_api)]
 #![feature(c_unwind)]
 #![feature(cfg_target_abi)]
